@@ -109,7 +109,7 @@ def getCategories():
             data.append(mods.split('.')[1])
     return data
 
-def getModule(moduleName):
+def getModule(moduleName, count_try=0):
     """Return's and load's a module into a variable passing a module name as parameter
 
     Parameters
@@ -129,7 +129,11 @@ def getModule(moduleName):
             sentence = 'modules.{category}.{mod}.{moduleName}.StartModule()'.format(category=m.split('.')[1], mod='_'.join(moduleName.split('_')[1:]), moduleName=moduleName)
             return eval(sentence)
 
-    Logger.printMessage('Looks like {mod} is not loaded on HackingTools. Look the first import in log. You could have some error in your code :)'.format(mod=moduleName), is_error=True)
+    if count_try <= 4:
+        __sleep(1)
+        return getModule(moduleName, count_try+1)
+    else:
+        Logger.printMessage('Looks like {mod} is not loaded on HackingTools. Look the first import in log. You could have some error in your code :)'.format(mod=moduleName), is_error=True)
 
 def getModules():
     data = []
@@ -599,8 +603,6 @@ if __telegrambot_token__:
 
 __importModules__()
 
-__sleep(3)
-
 # try:
 #     for t in threads:
 #         t.join()
